'use strict';

var React = require('react');

/******************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */
/* global Reflect, Promise, SuppressedError, Symbol */


var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

function __rest(s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
}

typeof SuppressedError === "function" ? SuppressedError : function (error, suppressed, message) {
    var e = new Error(message);
    return e.name = "SuppressedError", e.error = error, e.suppressed = suppressed, e;
};

var EButtonType;
(function (EButtonType) {
    /**
     * Button type enums
     */
    EButtonType["BUTTON"] = "button";
    EButtonType["SUBMIT"] = "submit";
    EButtonType["RESET"] = "reset";
})(EButtonType || (EButtonType = {}));

var Button = function (_a) {
    var btnStyle = _a.btnStyle, _b = _a.label, label = _b === void 0 ? "" : _b, _c = _a.btnType, btnType = _c === void 0 ? EButtonType.BUTTON : _c, disabled = _a.disabled, onClick = _a.onClick, buttonRef = _a.buttonRef, restProps = __rest(_a, ["btnStyle", "label", "btnType", "disabled", "onClick", "buttonRef"]);
    var handleOnClick = function (event) {
        if (disabled)
            return;
        if (onClick)
            onClick(event);
    };
    var buttonProps = {
        className: btnStyle,
        type: btnType,
        onClick: handleOnClick,
        ref: buttonRef,
        disabled: disabled,
    };
    return (React.createElement("button", __assign({}, buttonProps, restProps), label));
};

var Card = function (props) {
    var style = props.style, children = props.children;
    return (React.createElement("div", { className: style, "data-testid": "ccg-foundation-card" }, children));
};
var CardActionArea = function (props) {
    var style = props.style, children = props.children, onClick = props.onClick;
    var handleOnClick = function () {
        if (onClick)
            onClick();
    };
    return (React.createElement("div", { role: "link", tabIndex: 0, style: { cursor: "pointer" }, className: style, onClick: handleOnClick, "data-testid": "ccg-foundation-card-clickable" }, children));
};
var CardHeader = function (props) {
    var style = props.style, children = props.children, intro = props.intro, topImage = props.topImage, imgSRText = props.imgSRText, title = props.title, subTitle = props.subTitle;
    return (React.createElement("div", { className: style },
        intro && React.createElement("h6", null, intro),
        topImage && typeof topImage === "string" ? (React.createElement("img", { src: topImage, alt: imgSRText })) : (topImage),
        title && typeof title === "string" ? React.createElement("h2", null, title) : title,
        subTitle && React.createElement("p", null, subTitle),
        children));
};
var CardBody = function (props) {
    var style = props.style, children = props.children;
    return React.createElement("div", { className: style }, children);
};
var CardFooter = function (props) {
    var style = props.style, children = props.children;
    return React.createElement("div", { className: style }, children);
};
Card.ActionArea = CardActionArea;
Card.Header = CardHeader;
Card.Body = CardBody;
Card.Footer = CardFooter;

exports.Button = Button;
exports.Card = Card;
//# sourceMappingURL=index.js.map
